/**
 * Highly inspired from Dailymotion JS SDK available at https://github.com/dailymotion/dailymotion-sdk-js
 *
 * Copyright Work Bandits SAS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *
 *
 * JavaScript library providing Dailymtion API integration.
 *
 * @provides di.init
 * @requires di.prelude
 *           di.auth
 *           di.api
 *           di.cookie
 */

/**
 * This is the top level for all the public APIs.
 *
 * @class DI
 * @static
 * @access public
 */
DI.provide('', {
    init: function(options) {
        // only need to list values here that do not already have a falsy default.
        // this is why cookie/session/status are not listed here.
        options = DI.copy(options || {}, {
            logging: true
        });

        DI._apiKey = options.apiKey;

        // disable logging if told to do so, but only if the url doesnt have the
        // token to turn it on. this allows for easier debugging of third party
        // sites even if logging has been turned off.
        if (!options.logging && window.location.toString().indexOf('di_debug=1') < 0) {
            DI._logging = false;
        }

        if (DI._apiKey) {
            // enable cookie support if told to do so
            DI.Cookie.setEnabled(options.cookie);

            // if an explicit session was not given, try to _read_ an existing cookie.
            // we dont enable writing automatically, but we do read automatically.
            options.session = options.session || DI.Auth._receivedSession || DI.Cookie.load();

            // set the session
            DI.Auth.setSession(options.session, options.session ? 'connected' : 'unknown');

            // load a fresh session if requested
            if (options.status) {
                DI.getLoginStatus();
            }
        }

	    // add network navigation menu if diroot is here
	    var diroot = document.getElementById('diroot');
	    if (diroot != null) {
	        diroot.style.height = "29px";
	        diroot.style.width = "100%";

		    DI.api('/ui/user-infos', function(response) {
                // create orphan element set HTML to
                var orphNode = document.createElement('div');
                orphNode.innerHTML = response.html;

                // add html to place holder element (note: we are adding the html before we execute the scripts)
                diroot.innerHTML = orphNode.innerHTML;

                // execute stored scripts
                var head = document.getElementsByTagName('head')[0];
			
			    var cssNode = document.createElement('link');
			    cssNode.href = DI._domain['cdn'] + '/css/common/allopass.css';
			    cssNode.type = 'text/css';
			    cssNode.rel = 'stylesheet';
			    head.appendChild(cssNode);

			    cssNode = document.createElement('link');
			    cssNode.href = DI._domain['cdn'] + '/css/api/ui/user-infos.css';
			    cssNode.type = 'text/css';
			    cssNode.rel = 'stylesheet';
			    head.appendChild(cssNode);

				var scriptNode = document.createElement('script');
			    scriptNode.type = 'text/javascript';
			    scriptNode.src = DI._domain['cdn'] + '/js/libs/allopass.js';
			    head.appendChild(scriptNode);
				head.removeChild(scriptNode);

			    var response = {
			        session: DI._session,
			        status: DI._userStatus
			    };

			    DI.Event.fire('auth.statusChange', response);
		    });
	    }
    }
});

// this is useful when the library is being loaded asynchronously
//
// we do it in a setTimeout to wait until the current event loop as finished.
// this allows potential library code being included below this block (possible
// when being served from an automatically combined version)
window.setTimeout(function() { if (window.diAsyncInit) { diAsyncInit(); }}, 0);
