module('auth events');

test('verify subscriber gets notified on various events', function() {
    var expected = 5;

    var cb = function(response) {
        ok(true, 'subscriber got called');
        expected -= 1;
        if (expected < 0) {
            throw new Exception('got more auth events than expected');
        }
    };
    DI.Event.subscribe('auth.sessionChange', cb);

    action.innerHTML = ('Accept the connection');
    action.onclick = function() {
        // 1
        DI.login(function() {
            // 2
            DI.api('logout', function(response) {
                // 3
                action.innerHTML = ('Accept the connection again');
                action.onclick = function() {
                    DI.login(function() {
                        // 4
                        DI.logout(function() {
                            // 5
                            action.innerHTML = ('Accept the connection one more time');
                            action.onclick = function() {
                                DI.login(function() {
                                    action.innerHTML = ('Accept the connection one last time');
                                    action.onclick = function() {
                                        // should not trigger subscriber
                                        DI.login(function() {
                                            // 6
                                            ok(expected == 0, 'got all expected callbacks');

                                            // unsubscribe once we're done
                                            DI.Event.unsubscribe('auth.sessionChange', cb);
                                            action.innerHTML = '';
                                            start();
                                        }, {scope: 'write'});
                                    };
                                }, {scope: 'read'});
                            };
                        });
                    });
                };
            });
        });
    };
    action.className = 'session-subscribers';

    expect(expected + 1);
    stop();
  }
);

test('verify status event only gets fired once per change', function() {
    var expected = 2;
    expect(expected);
    stop();

    var oldSession = DI._session;
    var oldStatus = DI._userStatus;

    DI.Auth.setSession(EXPIRED_SESSION, 'connected');
    var cb = function(response) {
        ok(true, 'subscriber got called');
        expected -= 1;

        if (expected == 0) {
            // reset back
            DI._session = oldSession;
            DI._userStatus = oldStatus;
            start();
        }
    };
    DI.Event.subscribe('auth.statusChange', cb);
    DI.Auth.setSession(null, 'notConnected');
    DI.Auth.setSession(null, 'notConnected');
    DI.Auth.setSession(null, 'unknown');
});
